summaryrefslogtreecommitdiff
path: root/tools/llvm-bcanalyzer
diff options
context:
space:
mode:
authorGabor Greif <ggreif@gmail.com>2007-07-04 21:55:50 +0000
committerGabor Greif <ggreif@gmail.com>2007-07-04 21:55:50 +0000
commit8ff70c2635bfd4e02c0140a5dc9ca909fffba35a (patch)
tree1a5d1778b445da7fe5b42dd4e2eb585fe94a5fba /tools/llvm-bcanalyzer
parente377d4d142d7e2ec9266435087c99ffc43f394aa (diff)
downloadllvm-8ff70c2635bfd4e02c0140a5dc9ca909fffba35a.tar.gz
llvm-8ff70c2635bfd4e02c0140a5dc9ca909fffba35a.tar.bz2
llvm-8ff70c2635bfd4e02c0140a5dc9ca909fffba35a.tar.xz
Pretty straightforward replacement of "bytecode" by "bitcode"
performed on tools/ first, in order not to cause lethal damage git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@37877 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'tools/llvm-bcanalyzer')
-rw-r--r--tools/llvm-bcanalyzer/llvm-bcanalyzer.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/tools/llvm-bcanalyzer/llvm-bcanalyzer.cpp b/tools/llvm-bcanalyzer/llvm-bcanalyzer.cpp
index 1c96a2b3a8..126a2edc40 100644
--- a/tools/llvm-bcanalyzer/llvm-bcanalyzer.cpp
+++ b/tools/llvm-bcanalyzer/llvm-bcanalyzer.cpp
@@ -1,4 +1,4 @@
-//===-- llvm-bcanalyzer.cpp - Byte Code Analyzer --------------------------===//
+//===-- llvm-bcanalyzer.cpp - Bitcode Analyzer --------------------------===//
//
// The LLVM Compiler Infrastructure
//
@@ -8,22 +8,22 @@
//===----------------------------------------------------------------------===//
//
// This tool may be invoked in the following manner:
// llvm-bcanalyzer [options] - Read LLVM bytecode from stdin
// llvm-bcanalyzer [options] x.bc - Read LLVM bytecode from the x.bc file
//
// Options:
// --help - Output information about command line switches
// --dump - Dump low-level bytecode structure in readable format
//
// This tool provides analytical information about a bytecode file. It is
// intended as an aid to developers of bytecode reading and writing software. It
// produces on std::out a summary of the bytecode file that shows various
// statistics about the contents of the file. By default this information is
// detailed and contains information about individual bytecode blocks and the
// functions in the module.
// The tool is also able to print a bytecode file in a straight forward text
// format that shows the containment and relationships of the information in
// the bytecode file (-dump option).
//
//===----------------------------------------------------------------------===//
@@ -41,12 +41,12 @@
using namespace llvm;
static cl::opt<std::string>
- InputFilename(cl::Positional, cl::desc("<input bytecode>"), cl::init("-"));
+ InputFilename(cl::Positional, cl::desc("<input bitcode>"), cl::init("-"));
static cl::opt<std::string>
OutputFilename("-o", cl::init("-"), cl::desc("<output file>"));
-static cl::opt<bool> Dump("dump", cl::desc("Dump low level bytecode trace"));
+static cl::opt<bool> Dump("dump", cl::desc("Dump low level bitcode trace"));
//===----------------------------------------------------------------------===//
// Bitcode specific analysis.
@@ -8,22 +8,22 @@
//
// This tool may be invoked in the following manner:
-// llvm-bcanalyzer [options] - Read LLVM bytecode from stdin
-// llvm-bcanalyzer [options] x.bc - Read LLVM bytecode from the x.bc file
+// llvm-bcanalyzer [options] - Read LLVM bitcode from stdin
+// llvm-bcanalyzer [options] x.bc - Read LLVM bitcode from the x.bc file
//
// Options:
@@ -8,22 +8,22 @@
// Options:
// --help - Output information about command line switches
-// --dump - Dump low-level bytecode structure in readable format
+// --dump - Dump low-level bitcode structure in readable format
//
@@ -8,22 +8,22 @@
//
-// This tool provides analytical information about a bytecode file. It is
-// intended as an aid to developers of bytecode reading and writing software. It
-// produces on std::out a summary of the bytecode file that shows various
+// This tool provides analytical information about a bitcode file. It is
+// intended as an aid to developers of bitcode reading and writing software. It
+// produces on std::out a summary of the bitcode file that shows various
// statistics about the contents of the file. By default this information is
@@ -8,22 +8,22 @@
// statistics about the contents of the file. By default this information is
-// detailed and contains information about individual bytecode blocks and the
+// detailed and contains information about individual bitcode blocks and the
// functions in the module.
@@ -8,22 +8,22 @@
// functions in the module.
-// The tool is also able to print a bytecode file in a straight forward text
+// The tool is also able to print a bitcode file in a straight forward text
// format that shows the containment and relationships of the information in
@@ -8,22 +8,22 @@
// format that shows the containment and relationships of the information in
-// the bytecode file (-dump option).
+// the bitcode file (-dump option).
//
//===----------------------------------------------------------------------===//